GUI.Plugin.OverviewHeader = new function() {
  var _gui = null;
  var _data = null;
  var _header = document.getElementById('header');
  var _workspace = null;
  var _view = null;

  this.onresize = function()
  {
    var b = _header.clientHeight;
    for (var i = _header.firstChild; i; i = i.nextSibling)
    {
     var bottom = i.offsetTop + i.clientHeight;
     if (bottom > b)
       b = bottom;
    }

    var top = _header.nextSibling.offsetTop;
    if (top != b)
      _header.nextSibling.style.top = b + 'px';
  }

  this.heading = function(panel, label, content)
  {
    var hdiv = document.createElement("div");
    _header.insertBefore(hdiv, _header.lastChild);
    hdiv.className = 'heading' + (panel ? " with-panel" : "");
    hdiv.innerHTML = ("<div class='label'>" + label + "</div><h2>" + content + "</h2>"
		      + (panel ? "<div class='panel'></div>" : ""));
    return hdiv.childNodes[1];
  }

  this.attach = function(gui)
  {
    var panel;
    _gui = gui;
    _workspace = this.heading(true, "Workspace", "<span>_</span>").firstChild;
    _workspace.parentNode.nextSibling.innerHTML +=
      "<table id='hdr-workspace'><tbody></tbody></table>";
    _view = this.heading(true, "View", "<span>_</span>").firstChild;
    _view.parentNode.nextSibling.innerHTML +=
      "<table id='hdr-view'><tbody></tbody></table>";
    this.onresize();
  }

  this.detach = function()
  {
    _header.removeChild(_workspace.parentNode.parentNode);
    _header.removeChild(_view.parentNode.parentNode);
    _workspace = null;
    _view = null;
  }

  this.setWorkspace = function(choice)
  {
    _gui.makeCall(_url() + "/workspace?name=" + encodeURIComponent(choice));
    return false;
  }

  this.setView = function(choice)
  {
    _gui.makeCall(_url() + "/view?name=" + encodeURIComponent(choice));
    return false;
  }

  this.update = function(data)
  {
    _data = data;
    _workspace.innerHTML = data.workspace;
    _view.innerHTML = data.view;

    var title = data.workspace + " - " + HEADING;
    if (document.title != title)
      document.title = title;

    var table = document.getElementById('hdr-workspace').firstChild;
    var row = table.rows.length ? table.rows[0] : table.insertRow(-1);
    for (var i = 0, e = data.workspaces.length; i < e; ++i)
    {
      var item = data.workspaces[i];
      cell = i < row.cells.length ? row.cells[i] : row.insertCell(-1);

      var text;
      if (item.title != data.workspace)
	text = ("<a href='#' onclick=\"return GUI.Plugin.OverviewHeader"
		+ ".setWorkspace('" + item.label + "')\">" + item.title
		+ "</a>");
      else
	text = item.title;

      if (cell.innerHTML != text)
	cell.innerHTML = text;
    }

    while (row.childNodes.length > data.workspaces.length)
      row.removeChild(row.lastChild);

    var table = document.getElementById('hdr-view').firstChild;
    var row = table.rows.length ? table.rows[0] : table.insertRow(-1);
    for (var i = 0, e = data.views.length; i < e; ++i)
    {
      var item = data.views[i];
      cell = i < row.cells.length ? row.cells[i] : row.insertCell(-1);

      var text;
      if (item.title != data.view)
	text = ("<a href='#' onclick=\"return GUI.Plugin.OverviewHeader"
		+ ".setView('" + item.label + "')\">" + item.title
		+ "</a>");
      else
	text = item.title;

      if (cell.innerHTML != text)
	cell.innerHTML = text;
    }

    while (row.childNodes.length > data.views.length)
      row.removeChild(row.lastChild);
  }

  return this;
}();
